# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import EntityChangeDetailsClass
from .....schema_classes import EntityChangeTypeClass
from .....schema_classes import SubscriptionInfoClass
from .....schema_classes import SubscriptionNotificationConfigClass
from .....schema_classes import SubscriptionTypeClass


EntityChangeDetails = EntityChangeDetailsClass
EntityChangeType = EntityChangeTypeClass
SubscriptionInfo = SubscriptionInfoClass
SubscriptionNotificationConfig = SubscriptionNotificationConfigClass
SubscriptionType = SubscriptionTypeClass

# fmt: on
