# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import AnomalyInfoClass
from .....schema_classes import AnomalyReviewClass
from .....schema_classes import AnomalyReviewStateClass
from .....schema_classes import AnomalySourceClass
from .....schema_classes import AnomalySourcePropertiesClass
from .....schema_classes import AnomalySourceTypeClass
from .....schema_classes import AnomalyStateClass
from .....schema_classes import AnomalyStatusClass
from .....schema_classes import AnomalyStatusPropertiesClass
from .....schema_classes import AnomalyTypeClass


AnomalyInfo = AnomalyInfoClass
AnomalyReview = AnomalyReviewClass
AnomalyReviewState = AnomalyReviewStateClass
AnomalySource = AnomalySourceClass
AnomalySourceProperties = AnomalySourcePropertiesClass
AnomalySourceType = AnomalySourceTypeClass
AnomalyState = AnomalyStateClass
AnomalyStatus = AnomalyStatusClass
AnomalyStatusProperties = AnomalyStatusPropertiesClass
AnomalyType = AnomalyTypeClass

# fmt: on
