# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import ActionRequestArchivedClass
from .....schema_classes import ActionRequestInfoClass
from .....schema_classes import ActionRequestParamsClass
from .....schema_classes import ActionRequestStatusClass
from .....schema_classes import CreateGlossaryNodeProposalClass
from .....schema_classes import CreateGlossaryTermProposalClass
from .....schema_classes import DataContractProposalClass
from .....schema_classes import DataContractProposalOperationTypeClass
from .....schema_classes import DescriptionProposalClass
from .....schema_classes import GlossaryTermProposalClass
from .....schema_classes import TagProposalClass


ActionRequestArchived = ActionRequestArchivedClass
ActionRequestInfo = ActionRequestInfoClass
ActionRequestParams = ActionRequestParamsClass
ActionRequestStatus = ActionRequestStatusClass
CreateGlossaryNodeProposal = CreateGlossaryNodeProposalClass
CreateGlossaryTermProposal = CreateGlossaryTermProposalClass
DataContractProposal = DataContractProposalClass
DataContractProposalOperationType = DataContractProposalOperationTypeClass
DescriptionProposal = DescriptionProposalClass
GlossaryTermProposal = GlossaryTermProposalClass
TagProposal = TagProposalClass

# fmt: on
