# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import AssertionEvaluationParametersClass
from .....schema_classes import AssertionEvaluationParametersTypeClass
from .....schema_classes import AssertionEvaluationSpecClass
from .....schema_classes import AssertionMonitorClass
from .....schema_classes import AuditLogSpecClass
from .....schema_classes import DataHubOperationSpecClass
from .....schema_classes import DatasetFieldAssertionParametersClass
from .....schema_classes import DatasetFieldAssertionSourceTypeClass
from .....schema_classes import DatasetFreshnessAssertionParametersClass
from .....schema_classes import DatasetFreshnessSourceTypeClass
from .....schema_classes import DatasetVolumeAssertionParametersClass
from .....schema_classes import DatasetVolumeSourceTypeClass
from .....schema_classes import MonitorInfoClass
from .....schema_classes import MonitorModeClass
from .....schema_classes import MonitorStatusClass
from .....schema_classes import MonitorTimeseriesStateClass
from .....schema_classes import MonitorTypeClass


AssertionEvaluationParameters = AssertionEvaluationParametersClass
AssertionEvaluationParametersType = AssertionEvaluationParametersTypeClass
AssertionEvaluationSpec = AssertionEvaluationSpecClass
AssertionMonitor = AssertionMonitorClass
AuditLogSpec = AuditLogSpecClass
DataHubOperationSpec = DataHubOperationSpecClass
DatasetFieldAssertionParameters = DatasetFieldAssertionParametersClass
DatasetFieldAssertionSourceType = DatasetFieldAssertionSourceTypeClass
DatasetFreshnessAssertionParameters = DatasetFreshnessAssertionParametersClass
DatasetFreshnessSourceType = DatasetFreshnessSourceTypeClass
DatasetVolumeAssertionParameters = DatasetVolumeAssertionParametersClass
DatasetVolumeSourceType = DatasetVolumeSourceTypeClass
MonitorInfo = MonitorInfoClass
MonitorMode = MonitorModeClass
MonitorStatus = MonitorStatusClass
MonitorTimeseriesState = MonitorTimeseriesStateClass
MonitorType = MonitorTypeClass

# fmt: on
