# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from ......schema_classes import ActionRequestKeyClass
from ......schema_classes import AnomalyKeyClass
from ......schema_classes import AssertionKeyClass
from ......schema_classes import ChartKeyClass
from ......schema_classes import ConstraintKeyClass
from ......schema_classes import ContainerKeyClass
from ......schema_classes import CorpGroupKeyClass
from ......schema_classes import CorpUserKeyClass
from ......schema_classes import DashboardKeyClass
from ......schema_classes import DataContractKeyClass
from ......schema_classes import DataFlowKeyClass
from ......schema_classes import DataHubAccessTokenKeyClass
from ......schema_classes import DataHubConnectionKeyClass
from ......schema_classes import DataHubIngestionSourceKeyClass
from ......schema_classes import DataHubPolicyKeyClass
from ......schema_classes import DataHubRetentionKeyClass
from ......schema_classes import DataHubRoleKeyClass
from ......schema_classes import DataHubSecretKeyClass
from ......schema_classes import DataHubStepStateKeyClass
from ......schema_classes import DataHubUpgradeKeyClass
from ......schema_classes import DataHubViewKeyClass
from ......schema_classes import DataJobKeyClass
from ......schema_classes import DataPlatformInstanceKeyClass
from ......schema_classes import DataPlatformKeyClass
from ......schema_classes import DataProcessInstanceKeyClass
from ......schema_classes import DataProcessKeyClass
from ......schema_classes import DatasetKeyClass
from ......schema_classes import DomainKeyClass
from ......schema_classes import ExecutionRequestKeyClass
from ......schema_classes import GlobalSettingsKeyClass
from ......schema_classes import GlossaryNodeKeyClass
from ......schema_classes import GlossaryTermKeyClass
from ......schema_classes import IncidentKeyClass
from ......schema_classes import InviteTokenKeyClass
from ......schema_classes import LinkPreviewKeyClass
from ......schema_classes import MLFeatureKeyClass
from ......schema_classes import MLFeatureTableKeyClass
from ......schema_classes import MLModelDeploymentKeyClass
from ......schema_classes import MLModelGroupKeyClass
from ......schema_classes import MLModelKeyClass
from ......schema_classes import MLPrimaryKeyKeyClass
from ......schema_classes import MonitorKeyClass
from ......schema_classes import NotebookKeyClass
from ......schema_classes import OwnershipTypeKeyClass
from ......schema_classes import PostKeyClass
from ......schema_classes import QueryKeyClass
from ......schema_classes import RecommendationModuleKeyClass
from ......schema_classes import RoleKeyClass
from ......schema_classes import SchemaFieldKeyClass
from ......schema_classes import SubscriptionKeyClass
from ......schema_classes import TagKeyClass
from ......schema_classes import TelemetryKeyClass
from ......schema_classes import TestKeyClass


ActionRequestKey = ActionRequestKeyClass
AnomalyKey = AnomalyKeyClass
AssertionKey = AssertionKeyClass
ChartKey = ChartKeyClass
ConstraintKey = ConstraintKeyClass
ContainerKey = ContainerKeyClass
CorpGroupKey = CorpGroupKeyClass
CorpUserKey = CorpUserKeyClass
DashboardKey = DashboardKeyClass
DataContractKey = DataContractKeyClass
DataFlowKey = DataFlowKeyClass
DataHubAccessTokenKey = DataHubAccessTokenKeyClass
DataHubConnectionKey = DataHubConnectionKeyClass
DataHubIngestionSourceKey = DataHubIngestionSourceKeyClass
DataHubPolicyKey = DataHubPolicyKeyClass
DataHubRetentionKey = DataHubRetentionKeyClass
DataHubRoleKey = DataHubRoleKeyClass
DataHubSecretKey = DataHubSecretKeyClass
DataHubStepStateKey = DataHubStepStateKeyClass
DataHubUpgradeKey = DataHubUpgradeKeyClass
DataHubViewKey = DataHubViewKeyClass
DataJobKey = DataJobKeyClass
DataPlatformInstanceKey = DataPlatformInstanceKeyClass
DataPlatformKey = DataPlatformKeyClass
DataProcessInstanceKey = DataProcessInstanceKeyClass
DataProcessKey = DataProcessKeyClass
DatasetKey = DatasetKeyClass
DomainKey = DomainKeyClass
ExecutionRequestKey = ExecutionRequestKeyClass
GlobalSettingsKey = GlobalSettingsKeyClass
GlossaryNodeKey = GlossaryNodeKeyClass
GlossaryTermKey = GlossaryTermKeyClass
IncidentKey = IncidentKeyClass
InviteTokenKey = InviteTokenKeyClass
LinkPreviewKey = LinkPreviewKeyClass
MLFeatureKey = MLFeatureKeyClass
MLFeatureTableKey = MLFeatureTableKeyClass
MLModelDeploymentKey = MLModelDeploymentKeyClass
MLModelGroupKey = MLModelGroupKeyClass
MLModelKey = MLModelKeyClass
MLPrimaryKeyKey = MLPrimaryKeyKeyClass
MonitorKey = MonitorKeyClass
NotebookKey = NotebookKeyClass
OwnershipTypeKey = OwnershipTypeKeyClass
PostKey = PostKeyClass
QueryKey = QueryKeyClass
RecommendationModuleKey = RecommendationModuleKeyClass
RoleKey = RoleKeyClass
SchemaFieldKey = SchemaFieldKeyClass
SubscriptionKey = SubscriptionKeyClass
TagKey = TagKeyClass
TelemetryKey = TelemetryKeyClass
TestKey = TestKeyClass

# fmt: on
