# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .......schema_classes import CostCurrencyCodeClass
from .......schema_classes import CostFeaturesClass
from .......schema_classes import StorageFeaturesClass
from .......schema_classes import UsageFeaturesClass


CostCurrencyCode = CostCurrencyCodeClass
CostFeatures = CostFeaturesClass
StorageFeatures = StorageFeaturesClass
UsageFeatures = UsageFeaturesClass

# fmt: on
