# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import ChartCellClass
from .....schema_classes import EditableNotebookPropertiesClass
from .....schema_classes import NotebookCellClass
from .....schema_classes import NotebookCellTypeClass
from .....schema_classes import NotebookContentClass
from .....schema_classes import NotebookInfoClass
from .....schema_classes import QueryCellClass
from .....schema_classes import TextCellClass


ChartCell = ChartCellClass
EditableNotebookProperties = EditableNotebookPropertiesClass
NotebookCell = NotebookCellClass
NotebookCellType = NotebookCellTypeClass
NotebookContent = NotebookContentClass
NotebookInfo = NotebookInfoClass
QueryCell = QueryCellClass
TextCell = TextCellClass

# fmt: on
