# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import ArrayTypeClass
from .....schema_classes import BinaryJsonSchemaClass
from .....schema_classes import BooleanTypeClass
from .....schema_classes import BytesTypeClass
from .....schema_classes import DatasetFieldForeignKeyClass
from .....schema_classes import DateTypeClass
from .....schema_classes import EditableSchemaFieldInfoClass
from .....schema_classes import EditableSchemaMetadataClass
from .....schema_classes import EnumTypeClass
from .....schema_classes import EspressoSchemaClass
from .....schema_classes import FixedTypeClass
from .....schema_classes import ForeignKeyConstraintClass
from .....schema_classes import ForeignKeySpecClass
from .....schema_classes import KafkaSchemaClass
from .....schema_classes import KeyValueSchemaClass
from .....schema_classes import MapTypeClass
from .....schema_classes import MySqlDDLClass
from .....schema_classes import NullTypeClass
from .....schema_classes import NumberTypeClass
from .....schema_classes import OracleDDLClass
from .....schema_classes import OrcSchemaClass
from .....schema_classes import OtherSchemaClass
from .....schema_classes import PrestoDDLClass
from .....schema_classes import RecordTypeClass
from .....schema_classes import SchemaFieldClass
from .....schema_classes import SchemaFieldDataTypeClass
from .....schema_classes import SchemaFieldSpecClass
from .....schema_classes import SchemaMetadataClass
from .....schema_classes import SchemaProposalClass
from .....schema_classes import SchemaProposalsClass
from .....schema_classes import SchemalessClass
from .....schema_classes import StringTypeClass
from .....schema_classes import TimeTypeClass
from .....schema_classes import UnionTypeClass
from .....schema_classes import UrnForeignKeyClass


ArrayType = ArrayTypeClass
BinaryJsonSchema = BinaryJsonSchemaClass
BooleanType = BooleanTypeClass
BytesType = BytesTypeClass
DatasetFieldForeignKey = DatasetFieldForeignKeyClass
DateType = DateTypeClass
EditableSchemaFieldInfo = EditableSchemaFieldInfoClass
EditableSchemaMetadata = EditableSchemaMetadataClass
EnumType = EnumTypeClass
EspressoSchema = EspressoSchemaClass
FixedType = FixedTypeClass
ForeignKeyConstraint = ForeignKeyConstraintClass
ForeignKeySpec = ForeignKeySpecClass
KafkaSchema = KafkaSchemaClass
KeyValueSchema = KeyValueSchemaClass
MapType = MapTypeClass
MySqlDDL = MySqlDDLClass
NullType = NullTypeClass
NumberType = NumberTypeClass
OracleDDL = OracleDDLClass
OrcSchema = OrcSchemaClass
OtherSchema = OtherSchemaClass
PrestoDDL = PrestoDDLClass
RecordType = RecordTypeClass
SchemaField = SchemaFieldClass
SchemaFieldDataType = SchemaFieldDataTypeClass
SchemaFieldSpec = SchemaFieldSpecClass
SchemaMetadata = SchemaMetadataClass
SchemaProposal = SchemaProposalClass
SchemaProposals = SchemaProposalsClass
Schemaless = SchemalessClass
StringType = StringTypeClass
TimeType = TimeTypeClass
UnionType = UnionTypeClass
UrnForeignKey = UrnForeignKeyClass

# fmt: on
