# Autogenerated by datahub's custom_package_codegen.py
# DO NOT EDIT THIS FILE DIRECTLY

from setuptools import setup

_package_name = "acryl-datahub-cloud"
_package_version = "0.2.13.4"

setup(
    name=_package_name,
    version=_package_version,
    install_requires=[
        "avro-gen3==0.7.11",
        "acryl-datahub",
    ],
    entry_points={
        "datahub.custom_packages": [
            "models=acryl_datahub_cloud.models.schema_classes",
        ],
    },
)
